from django.conf import settings
from django.forms.widgets import MultiWidget
from django.forms import Select
from django.template import loader, Context

from .licences import ContentLicence, DEFAULT_LICENCE, LICENCE_CHOICES, LICENCE_VERSION_CHOICES

class LicenceSelectWidget(MultiWidget):

    template_name = 'content_licencing/widgets/licence_select_widget.html'

    def __init__(self, attrs={}):
        
        widgets = (
            Select(choices=LICENCE_CHOICES, attrs=attrs), # licence short_name
            Select(attrs=attrs), # licence version, choices depend on licence
        )
        super().__init__(widgets, attrs)
        

    def decompress(self, content_licence):

        if content_licence is None:
            return [None, None]

        data_list = [content_licence.short_name, content_licence.version]
        
        return data_list


    def get_context(self, name, value, attrs):

        if not value:
            value = DEFAULT_LICENCE

        if not isinstance(value, list):
            value = self.decompress(value)

        self.widgets[1].choices = LICENCE_VERSION_CHOICES[value[0]]
        
        context = super().get_context(name, value, attrs)


        template_version_choices = {}

        for short_name, versions in LICENCE_VERSION_CHOICES.items():

            choices = sorted([version_tuple[0] for version_tuple in versions])
            template_version_choices[short_name] = choices

        final_attrs = context['widget']['attrs']
        id_ = final_attrs.get('id')

        context['licence_version_choices'] = template_version_choices
        context['id_base'] = id_

        return context



from django.contrib.contenttypes.models import ContentType
from .models import ContentLicenceRegistry

class LicencingFormViewMixin:

    # instance might be "None" or something that does not exist
    def set_licence_registry_entry(self, instance, model_field):

        # the licence registry has to be stored for the ImageStore db entry
        self.licence_registry_entry = None
        if instance:
            content_type = ContentType.objects.get_for_model(instance)
            self.licence_registry_entry = ContentLicenceRegistry.objects.filter(content_type=content_type,
                                            object_id=instance.id, model_field=model_field).first()
        

    def get_licencing_initial(self):
        initial = {}
        
        if self.licence_registry_entry:
            initial['creator_name'] = self.licence_registry_entry.creator_name
            initial['creator_link'] = self.licence_registry_entry.creator_link
            initial['source_link'] = self.licence_registry_entry.source_link
            initial['licence'] = self.licence_registry_entry.content_licence()

        return initial
    

    def register_content_licence(self, form, instance, model_field):
        # register content licence
        licence_kwargs = {
            'creator_name' : form.cleaned_data['creator_name'],
            'creator_link' : form.cleaned_data['creator_link'],
            'source_link' : form.cleaned_data['source_link'],
        }
        registry_entry = ContentLicenceRegistry.objects.register(instance, model_field, self.request.user,
                            form.cleaned_data['licence'].short_name, form.cleaned_data['licence'].version,
                            **licence_kwargs)
        



from django import forms
from django.utils.translation import ugettext_lazy as _
from django.db.models.fields import BLANK_CHOICE_DASH
from django.forms.utils import ErrorList

from django.conf import settings

from django.contrib.contenttypes.models import ContentType

from .models import ContentLicenceRegistry

from .mixins import LicencingFormMixin, HELP_TEXTS
'''
    self.instance is the ContentLicenceRegistry instance
    self.content_instance is the content_instance which content_fields will be licenced

    the form can be initialized with or without the instance to be licenced in order to make
    it usable together with the creation of the instance. however, the save() method
    can only be called if self.content_instance is not None
'''

class ContentLicencingForm(LicencingFormMixin, forms.ModelForm):

    content_field = None
    
    def __init__(self, data=None, files=None, auto_id='id_%s', prefix=None,
                 initial=None, error_class=ErrorList, label_suffix=None,
                 empty_permitted=False, instance=None, content_instance=None, content_field=None):
        
        self.content_instance = content_instance

        if content_field is not None:
            self.content_field = content_field

        if not self.content_field:
            raise ValueError('ContentLicencingForm needs a content_field attribute')

        # ContentLicencingForm never receives an instance. The instance is fetched using the content_instance
        # and the field
        if self.content_instance is not None:
            instance = self.get_licence_registry_entry(self.content_instance)
            

        super().__init__(data=data, files=files, auto_id=auto_id, prefix=prefix,
                                           initial=initial, error_class=error_class, label_suffix=label_suffix,
                                           empty_permitted=empty_permitted, instance=instance)

        
    def save(self, commit=True):
        """
        Saves this ``form``'s cleaned_data into model instance
        ``self.instance``.

        If commit=True, then the changes to ``instance`` will be saved to the
        database. Returns ``instance``.
        """
        """
        Register the licence with the given content_instance and content_field
        """

        if self.content_instance is None:
            raise ValueError("ContentLicencingForm can only be save if it has self.content_instance")
        
        return super().save(commit=commit)


    def get_licence_registry_entry(self, instance):

        instance_content_type = ContentType.objects.get_for_model(instance)
        
        licencing_instance = ContentLicenceRegistry.objects.filter(
            content_type = instance_content_type,
            object_id = instance.pk,
            model_field = self.content_field,
        ).first()

        return licencing_instance
        

    class Meta:
        model = ContentLicenceRegistry
        fields = ["creator_name", "creator_link", "source_link", "licence", "licence_version", "uploader"]

        widgets = {
            "source_link" : forms.TextInput,
            "uploader" : forms.HiddenInput,
        }

        help_texts = HELP_TEXTS
    
    



from django.conf import settings
from django import forms
from django.utils.translation import ugettext_lazy as _

from .models import ContentLicenceRegistry
from .licences import LICENCE_CHOICES, DEFAULT_LICENCE, ContentLicence
from .fields import LicenceField

HELP_TEXTS = {
    'creator_name' : _('The full name of the entity which created this content. If the content is owned by the public and the original creator is unknown put in your full personal name.'),
    'source_link' : _('Direct link to the image or text'),
    'creator_link' : _('Link to the creators website'),
}


class GetLicenceMixin:

    def get_licence_as_dict(self):

        content_licence = self.cleaned_data['licence']
        
        licence = {
            'creator_name' : self.cleaned_data['creator_name'],
            'licence' : content_licence.as_dict(),
            'creator_link' : self.cleaned_data.get('creator_link', None),
            'source_link' : self.cleaned_data.get('source_link', None),
        }

        return licence


class LicencingFormMixin(GetLicenceMixin, forms.Form):

    creator_name = forms.CharField(help_text=HELP_TEXTS['creator_name'])
    creator_link = forms.CharField(help_text=HELP_TEXTS['creator_link'], required=False)
    source_link = forms.CharField(help_text=HELP_TEXTS['source_link'], required=False)
    licence = LicenceField(initial=DEFAULT_LICENCE)


class OptionalLicencingFormMixin(GetLicenceMixin, forms.Form):
    creator_name = forms.CharField(help_text=HELP_TEXTS['creator_name'], required=False)
    creator_link = forms.CharField(help_text=HELP_TEXTS['creator_link'], required=False)
    source_link = forms.CharField(help_text=HELP_TEXTS['source_link'], required=False)
    licence = LicenceField(initial=DEFAULT_LICENCE, required=False)
    

    
    



# Generated by Django 2.0.5 on 2019-07-06 09:28

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('contenttypes', '0002_remove_content_type_name'),
    ]

    operations = [
        migrations.CreateModel(
            name='ContentLicenceRegistry',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('object_id', models.IntegerField()),
                ('model_field', models.CharField(max_length=255)),
                ('uploaded_at', models.DateTimeField(auto_now_add=True)),
                ('last_modified_at', models.DateTimeField(auto_now=True)),
                ('licence', models.CharField(choices=[('All Rights Reserved', 'All Rights Reserved'), ('PDM', 'Public Domain Mark'), ('CC0', 'Public Domain Dedication'), ('CC BY', 'Creative Commons Attribution'), ('CC BY-SA', 'Creative Commons Attribution-ShareAlike'), ('CC BY-ND', 'Creative Commons Attribution-NoDerivs'), ('CC BY-NC', 'Creative Commons Attribution-NonCommercial'), ('CC BY-NC-SA', 'Creative Commons Attribution-NonCommercial-ShareAlike'), ('CC BY-NC-ND', 'Creative Commons Attribution-NonCommercial-NoDerivs')], default={'short_name': 'CC0', 'version': '1.0'}, max_length=100)),
                ('licence_version', models.CharField(max_length=10)),
                ('creator_name', models.CharField(max_length=355)),
                ('creator_link', models.CharField(blank=True, max_length=355, null=True)),
                ('source_link', models.TextField(blank=True, null=True)),
                ('language', models.CharField(choices=[('af', 'Afrikaans'), ('ar', 'Arabic'), ('ast', 'Asturian'), ('az', 'Azerbaijani'), ('bg', 'Bulgarian'), ('be', 'Belarusian'), ('bn', 'Bengali'), ('br', 'Breton'), ('bs', 'Bosnian'), ('ca', 'Catalan'), ('cs', 'Czech'), ('cy', 'Welsh'), ('da', 'Danish'), ('de', 'German'), ('dsb', 'Lower Sorbian'), ('el', 'Greek'), ('en', 'English'), ('en-au', 'Australian English'), ('en-gb', 'British English'), ('eo', 'Esperanto'), ('es', 'Spanish'), ('es-ar', 'Argentinian Spanish'), ('es-co', 'Colombian Spanish'), ('es-mx', 'Mexican Spanish'), ('es-ni', 'Nicaraguan Spanish'), ('es-ve', 'Venezuelan Spanish'), ('et', 'Estonian'), ('eu', 'Basque'), ('fa', 'Persian'), ('fi', 'Finnish'), ('fr', 'French'), ('fy', 'Frisian'), ('ga', 'Irish'), ('gd', 'Scottish Gaelic'), ('gl', 'Galician'), ('he', 'Hebrew'), ('hi', 'Hindi'), ('hr', 'Croatian'), ('hsb', 'Upper Sorbian'), ('hu', 'Hungarian'), ('ia', 'Interlingua'), ('id', 'Indonesian'), ('io', 'Ido'), ('is', 'Icelandic'), ('it', 'Italian'), ('ja', 'Japanese'), ('ka', 'Georgian'), ('kab', 'Kabyle'), ('kk', 'Kazakh'), ('km', 'Khmer'), ('kn', 'Kannada'), ('ko', 'Korean'), ('lb', 'Luxembourgish'), ('lt', 'Lithuanian'), ('lv', 'Latvian'), ('mk', 'Macedonian'), ('ml', 'Malayalam'), ('mn', 'Mongolian'), ('mr', 'Marathi'), ('my', 'Burmese'), ('nb', 'Norwegian Bokmål'), ('ne', 'Nepali'), ('nl', 'Dutch'), ('nn', 'Norwegian Nynorsk'), ('os', 'Ossetic'), ('pa', 'Punjabi'), ('pl', 'Polish'), ('pt', 'Portuguese'), ('pt-br', 'Brazilian Portuguese'), ('ro', 'Romanian'), ('ru', 'Russian'), ('sk', 'Slovak'), ('sl', 'Slovenian'), ('sq', 'Albanian'), ('sr', 'Serbian'), ('sr-latn', 'Serbian Latin'), ('sv', 'Swedish'), ('sw', 'Swahili'), ('ta', 'Tamil'), ('te', 'Telugu'), ('th', 'Thai'), ('tr', 'Turkish'), ('tt', 'Tatar'), ('udm', 'Udmurt'), ('uk', 'Ukrainian'), ('ur', 'Urdu'), ('vi', 'Vietnamese'), ('zh-hans', 'Simplified Chinese'), ('zh-hant', 'Traditional Chinese')], max_length=2, null=True)),
                ('sha256', models.CharField(max_length=355)),
                ('content_type', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='contenttypes.ContentType')),
            ],
        ),
    ]



from . import settings

# create licencing choices from settings
LICENCE_CHOICES = []

LICENCE_VERSION_CHOICES = {
}

# default is the lates available version
LICENCE_DEFAULT_VERSIONS = {}

for choice in settings.CONTENT_LICENCING_LICENCES:
    licence_choice = (
        choice['short_name'], choice['full_name']
    )

    LICENCE_CHOICES.append(licence_choice)

    version_choices = []
    latest_version = None
    for version, link in choice['versions'].items():

        if latest_version == None or float(version) > float(latest_version):
            latest_version = version
        
        version_choice = (
            version, version
        )
        version_choices.append(version_choice)

    LICENCE_VERSION_CHOICES[choice['short_name']] = version_choices
    LICENCE_DEFAULT_VERSIONS[choice['short_name']] = latest_version


class ContentLicence:

    def __init__(self, short_name, version=None):
        self.short_name = short_name

        if version == None:
            version = LICENCE_DEFAULT_VERSIONS[short_name]
        
        self.version = version

    def as_dict(self):
        dic = {
            'short_name' : self.short_name,
            'version' : self.version,
        }

        return dic

        
DEFAULT_LICENCE = ContentLicence(settings.CONTENT_LICENCING_DEFAULT_LICENCE['short_name'],
                                 settings.CONTENT_LICENCING_DEFAULT_LICENCE['version'])



from django.db import models
from django.conf import settings

from . import settings as content_licencing_settings

try:
    from django.contrib.contenttypes.generic import GenericForeignKey
except:
    from django.contrib.contenttypes.fields import GenericForeignKey

from django.contrib.contenttypes.models import ContentType

from django.db.models.fields.files import ImageFieldFile

import hashlib

from .licences import LICENCE_CHOICES, ContentLicence

'''
    Model to maintain licensing of user generated/uploaded content. This covers
    e.g. images and text.

    There a serveral use cases:
    1. User uploads content he does not own, but which he is allowed to use

    2. user uploads content he created

    3. user creates content which is changed by others afterwards
    - contributors is used

    if an image is used on several locations, every location will be registered in the
    registry

    To prefill a licence form if the same image is uploaded again, a sha256 is stored
'''

class ContentLicenceRegistryManager(models.Manager):

    # the register method registers newly created content and adds
    # users to contributors if the object already is registered
    # the licence is not changed if it already existed
    def register(self, instance, field, user, licence, licence_version, **kwargs):

        licence_reg = self.model.objects.filter(
            content_type = ContentType.objects.get_for_model(instance),
            object_id = instance.id,
            model_field = field,
        ).first()
        
        if not licence_reg:

            # add uploader in creation
            # if the owner differs from the uploader, this has to be in kwargs
            licence_reg = self.model(
                content_type = ContentType.objects.get_for_model(instance),
                object_id = instance.id,
                model_field = field,
                uploader = user,
                **kwargs
            )

        licence_reg.licence = licence
        licence_reg.licence_version = licence_version
        licence_reg.save()


        if user != licence_reg.uploader:
            licence_reg.contributors.add(user)

        # cannot return instance - it can be multiple fields resulting in multiple registry entries


class ContentLicenceRegistry(models.Model):

    content_type = models.ForeignKey(ContentType, on_delete=models.CASCADE)
    object_id = models.IntegerField()
    content = GenericForeignKey('content_type', 'object_id')
    model_field = models.CharField(max_length=255)
    uploader = models.ForeignKey(settings.AUTH_USER_MODEL, on_delete=models.SET_NULL, null=True) # the user who inserted text/images into a form field
    uploaded_at = models.DateTimeField(auto_now_add=True)
    last_modified_at = models.DateTimeField(auto_now=True)
    licence = models.CharField(max_length=100, choices=LICENCE_CHOICES,
                               default=content_licencing_settings.CONTENT_LICENCING_DEFAULT_LICENCE)
    licence_version = models.CharField(max_length=10)
    creator_name = models.CharField(max_length=355) # first an last name/ company name of the owner, if not the user
    creator_link = models.CharField(max_length=355, null=True, blank=True) # link to owner website
    source_link = models.TextField(null=True, blank=True) # direct link to source text/source image
    language = models.CharField(max_length=2, choices=settings.LANGUAGES, null=True)
    sha256 = models.CharField(max_length=355)

    contributors = models.ManyToManyField(settings.AUTH_USER_MODEL, related_name='contributors')

    objects = ContentLicenceRegistryManager()

    def content_licence(self):
        return ContentLicence(self.licence, self.licence_version)

    def save(self, *args, **kwargs):
        content = getattr(self.content, self.model_field)
        if type(content) == ImageFieldFile:
            with open(content.path, "rb") as f:
                self.sha256 = hashlib.sha256(f.read()).hexdigest()

        else:
            self.sha256 = hashlib.sha256(content).hexdigest()
        super().save(*args, **kwargs)

    class Meta:
        unique_together = ('content_type', 'object_id', 'model_field', 'language')

        
        



from django.shortcuts import render
from django.views.generic import FormView

from .forms import ContentLicencingForm


'''
    Subclass of FormView, adding the ModelForm named ContentLinceningForm
    The result is a FormView with two forms: licencing_form and the user defined form
    Support the licencing of one single field
'''
class LicencingFormView(FormView):
    licencing_form_class = ContentLicencingForm

    content_field = None

    def __init__(self, **kwargs):

        self.content_instance = None
        super().__init__(**kwargs)

        if not self.content_field:
            raise ValueError("LicencingFormView needs a content_field attribute")


    def get_licencing_form_kwargs(self):
        """
        Returns the keyword arguments for instantiating the licencing form.
        """
        kwargs = {
            'initial': self.get_initial(),
            'prefix': self.get_prefix(),
            'content_field' : self.content_field,
        }

        if self.request.method in ('POST', 'PUT'):
            kwargs.update({
                'data': self.request.POST,
                'files': self.request.FILES,
            })

        # ContentLicencingForm fetches the ContentLicenceRegistry Instance using content_instance and content_field
        if hasattr(self, 'content_instance'):
            kwargs.update({'content_instance': self.content_instance})

        return kwargs

    def get_licencing_form_class(self):
        """
        Returns the form class to use in this view
        """
        return self.licencing_form_class

    def get_licencing_form(self, licencing_form_class=None):
        """
        Returns an instance of the licencing form to be used in this view.
        """
        if licencing_form_class is None:
            licencing_form_class = self.get_licencing_form_class()
        return licencing_form_class(**self.get_licencing_form_kwargs())
    

    def get(self, request, *args, **kwargs):
        """
        Handles GET requests and instantiates a blank version of the form.
        """
        form = self.get_form()
        licencing_form = self.get_licencing_form()
        return self.render_to_response(self.get_context_data(form=form, licencing_form=licencing_form))

    def post(self, request, *args, **kwargs):
        """
        Handles POST requests, instantiating a form instance with the passed
        POST variables and then checked for validity.
        """
        form = self.get_form()
        licencing_form = self.get_licencing_form()
        if form.is_valid() and licencing_form.is_valid():
            return self.form_valid(form, licencing_form)
        else:
            return self.form_invalid(form, licencing_form)


    def form_valid(self, form, licencing_form):
        """
        The superclass (FormView) only accepts form
        if the form_view has a content_instance, create self.object
        """
        if self.content_instance:
            self.object = licencing_form.save()
        return super().form_valid(form)

    def form_invalid(self, form, licencing_form):
        """
        If the form is invalid, re-render the context data with the
        data-filled form and errors.
        """
        return self.render_to_response(self.get_context_data(form=form, licencing_form=licencing_form))




# Generated by Django 2.0.5 on 2019-07-06 09:28

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('content_licencing', '0001_initial'),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.AddField(
            model_name='contentlicenceregistry',
            name='contributors',
            field=models.ManyToManyField(related_name='contributors', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='contentlicenceregistry',
            name='uploader',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterUniqueTogether(
            name='contentlicenceregistry',
            unique_together={('content_type', 'object_id', 'model_field', 'language')},
        ),
    ]



from django.conf import settings

# content_licencing
DEFAULT_CONTENT_LICENCING_LICENCES = [
    {'short_name' : 'All Rights Reserved', 'full_name':'All Rights Reserved', 'versions':{
            '1.0': None,
        },
    },
    {'short_name' : 'PDM', 'full_name': 'Public Domain Mark', 'versions':{
            '1.0' : 'https://creativecommons.org/publicdomain/mark/1.0/',
        },
    },
    {'short_name' : 'CC0', 'full_name':'Public Domain Dedication', 'versions':{
            '1.0' : 'https://creativecommons.org/publicdomain/zero/1.0/',
        },
    },
    {'short_name' : 'CC BY', 'full_name':'Creative Commons Attribution', 'versions':{
            '1.0' : 'https://creativecommons.org/licenses/by/1.0/',
            '2.0' : 'https://creativecommons.org/licenses/by/2.0/',
            '2.5' : 'https://creativecommons.org/licenses/by/2.5/',
            '3.0' : 'https://creativecommons.org/licenses/by/3.0/',
            '4.0' : 'https://creativecommons.org/licenses/by/4.0/',
        },
    },
    {'short_name' : 'CC BY-SA', 'full_name':'Creative Commons Attribution-ShareAlike', 'versions':{
            '1.0' : 'https://creativecommons.org/licenses/by-sa/1.0/',
            '2.0' : 'https://creativecommons.org/licenses/by-sa/2.0/',
            '2.5' : 'https://creativecommons.org/licenses/by-sa/2.5/',
            '3.0' : 'https://creativecommons.org/licenses/by-sa/3.0/',
            '4.0' : 'https://creativecommons.org/licenses/by-sa/4.0/',
        },
    },
    {'short_name' : 'CC BY-ND', 'full_name':'Creative Commons Attribution-NoDerivs', 'versions':{
            '1.0' : 'https://creativecommons.org/licenses/by-nd/1.0/',
            '2.0' : 'https://creativecommons.org/licenses/by-nd/2.0/',
            '2.5' : 'https://creativecommons.org/licenses/by-nd/2.5/',
            '3.0' : 'https://creativecommons.org/licenses/by-nd/3.0/',
            '4.0' : 'https://creativecommons.org/licenses/by-nd/4.0/',
        },
    },
    {'short_name' : 'CC BY-NC', 'full_name':'Creative Commons Attribution-NonCommercial', 'versions':{
            '1.0' : 'https://creativecommons.org/licenses/by-nc/1.0/',
            '2.0' : 'https://creativecommons.org/licenses/by-nc/2.0/',
            '2.5' : 'https://creativecommons.org/licenses/by-nc/2.5/',
            '3.0' : 'https://creativecommons.org/licenses/by-nc/3.0/',
            '4.0' : 'https://creativecommons.org/licenses/by-nc/4.0/',
        },
    },
    {'short_name' : 'CC BY-NC-SA', 'full_name':'Creative Commons Attribution-NonCommercial-ShareAlike', 'versions':{
            '1.0' : 'https://creativecommons.org/licenses/by-nc-sa/1.0/',
            '2.0' : 'https://creativecommons.org/licenses/by-nc-sa/2.0/',
            '2.5' : 'https://creativecommons.org/licenses/by-nc-sa/2.5/',
            '3.0' : 'https://creativecommons.org/licenses/by-nc-sa/3.0/',
            '4.0' : 'https://creativecommons.org/licenses/by-nc-sa/4.0/',
        },
    },
    {'short_name' : 'CC BY-NC-ND', 'full_name':'Creative Commons Attribution-NonCommercial-NoDerivs', 'versions':{
            '1.0' : 'https://creativecommons.org/licenses/by-nc-nd/1.0/',
            '2.0' : 'https://creativecommons.org/licenses/by-nc-nd/2.0/',
            '2.5' : 'https://creativecommons.org/licenses/by-nc-nd/2.5/',
            '3.0' : 'https://creativecommons.org/licenses/by-nc-nd/3.0/',
            '4.0' : 'https://creativecommons.org/licenses/by-nc-nd/4.0/',
        },
    },
]

DEFAULT_CONTENT_LICENCING_DEFAULT_LICENCE = {
    'short_name' : 'CC0',
    'version' : '1.0',
}


CONTENT_LICENCING_LICENCES = getattr(settings, 'CONTENT_LICENCING_LICENCES', DEFAULT_CONTENT_LICENCING_LICENCES)

CONTENT_LICENCING_DEFAULT_LICENCE = getattr(settings, 'CONTENT_LICENCING_DEFAULT_LICENCE',
                                            DEFAULT_CONTENT_LICENCING_DEFAULT_LICENCE)



from django import forms

from .licences import ContentLicence
from .widgets import LicenceSelectWidget

class LicenceField(forms.MultiValueField):

    widget = LicenceSelectWidget

    def __init__(self, *args, **kwargs):
        
        fields = (
            forms.CharField(),
            forms.CharField(),
        )
        super().__init__(fields, *args, **kwargs)


    def compress(self, data_list):

        if data_list and len(data_list) == 2 and len(data_list[0]) > 0 and len(data_list[1]) >0:

            short_name = data_list[0]
            version = data_list[1]

            content_licence = ContentLicence(short_name, version)

            return content_licence

        return None



from setuptools import setup, find_packages

with open('README.md', 'r') as fh:
    long_description = fh.read()

install_requires = []

setup(
    name='content_licencing',
    version='0.2',
    description='Content licencing for django',
    long_description=long_description,
    long_description_content_type='text/markdown',
    license='The MIT License',
    platforms=['OS Independent'],
    keywords='django, licence',
    author='Thomas Uher',
    author_email='thomas.uher@sisol-systems.com',
    url='https://github.com/SiSol-Systems/content-licencing',
    packages=find_packages(),
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.6',
    include_package_data=True,
    install_requires=install_requires,
)
